@@ -2,19 +2,17 @@ use flexi_logger::{Duplicate, FileSpec, Logger};
 use log::{debug, info};
 use std::collections::HashMap;
 use std::str::FromStr;
-use ticket2ride::{max_key, City};
+use ticket2ride::{max_key, routing, scoring, City};
 
 mod cli;
 mod experiment;
-mod routing;
-mod scoring;
 
 fn main() {
     // Get command line options
     let matches = cli::get_cli().get_matches();
 
     // Setup logging first
-    Logger::try_with_env_or_str(matches.value_of("logging").unwrap_or("none"))
+    Logger::try_with_str(matches.value_of("logging").unwrap_or("none"))
         .unwrap()
         .log_to_file(FileSpec::default())
         .duplicate_to_stderr(Duplicate::Info)
